"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileUploader = void 0;
var AutomationTestLog_1 = require("../models/AutomationTestLog");
var Finder_1 = require("./Finder");
var Saver_1 = require("./Saver");
var JUnitTestCase_1 = require("../models/test_result_models/JUnitTestCase");
var xml2js = require("xml2js");
var FileUploader = /** @class */ (function () {
    function FileUploader(host, token) {
        this.finder = new Finder_1.Finder(host, token);
        this.saver = new Saver_1.Saver(host, token);
        this.uploadNew = false;
    }
    FileUploader.prototype.debug = function (bool) {
        this.finder.debug(bool);
        this.saver.debug(bool);
        return this;
    };
    FileUploader.prototype.uploadJUnitResults = function (xml) {
        var _this = this;
        return this.parseXML(xml).then(function (json) {
            return _this.finder.findTestRunsInModule(_this.projectId, _this.moduleId, _this.moduleType).then(function (testRuns) {
                var jUnitTestCases = _this.getJUnitTestCases(json);
                var promises = [];
                for (var _i = 0, jUnitTestCases_1 = jUnitTestCases; _i < jUnitTestCases_1.length; _i++) {
                    var testCase = jUnitTestCases_1[_i];
                    for (var _a = 0, testRuns_1 = testRuns; _a < testRuns_1.length; _a++) {
                        var testRun = testRuns_1[_a];
                        if (testCase.id == testRun.testCaseId) {
                            var log = new AutomationTestLog_1.AutomationTestLog();
                            log.status = testCase.status;
                            log.executionStartDate = new Date().toISOString();
                            log.executionEndDate = new Date().toISOString();
                            log.name = "QTM.FileUploader";
                            log.automationContent = "QTM.FileUploader";
                            log.note = "Uploaded with qtestmanager-node";
                            log.projectId = _this.projectId;
                            log.testRunId = testRun.id;
                            promises.push(_this.saver.saveNew(log));
                        }
                    }
                }
                return Promise.all(promises);
            });
        });
    };
    FileUploader.prototype.parseXML = function (xml) {
        var parser = new xml2js.Parser();
        return new Promise(function (resolve, reject) {
            parser.parseString(xml, function (err, json) {
                if (err) {
                    reject(err);
                }
                else {
                    resolve(json);
                }
            });
        });
    };
    FileUploader.prototype.getJUnitTestCases = function (json) {
        if (json.testsuites) {
            var testCases = [];
            var suites = json.testsuites.testsuite;
            for (var _i = 0, suites_1 = suites; _i < suites_1.length; _i++) {
                var suite = suites_1[_i];
                testCases = testCases.concat(this._getMatchingTestCases(suite.testcase));
            }
            return testCases;
        }
        else {
            return this._getMatchingTestCases(json.testsuite.testcase);
        }
    };
    FileUploader.prototype._getMatchingTestCases = function (testCases) {
        var testCaseArray = [];
        for (var _i = 0, testCases_1 = testCases; _i < testCases_1.length; _i++) {
            var testCase = testCases_1[_i];
            var regex = this.testNameRegex || /#(\d+)/;
            var idMatch = testCase.$.name.match(regex);
            if (idMatch) {
                var status_1 = "failure" in testCase ? "FAIL" : "PASS";
                testCaseArray.push(new JUnitTestCase_1.JUnitTestCase(idMatch[1], status_1));
            }
        }
        return testCaseArray;
    };
    return FileUploader;
}());
exports.FileUploader = FileUploader;
