"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Requester = void 0;
var axios = require('axios').default;
var Requester = /** @class */ (function () {
    function Requester(host) {
        this._driver = axios.create({ baseURL: host });
    }
    Object.defineProperty(Requester.prototype, "header", {
        set: function (header) {
            this._driver.defaults.headers[header.name] = header.value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Requester.prototype, "driver", {
        get: function () {
            return this._driver;
        },
        enumerable: false,
        configurable: true
    });
    Requester.prototype.debug = function (on) {
        if (on) {
            this._reqInterceptor = this._driver.interceptors.request.use(function (config) {
                console.log("----- Request -----");
                console.log(config.method, config.url);
                console.log(config.headers);
                console.log(config.data);
                console.log("----- End Request -----");
                return config;
            }, function (error) {
                return Promise.reject(error);
            });
            this._resInterceptor = this._driver.interceptors.response.use(function (response) {
                console.log("----- Response -----");
                console.log(response.headers);
                console.log(response.data);
                console.log("----- End Response -----");
                return response;
            }, function (error) {
                return Promise.reject(error);
            });
        }
        else {
            if (this._reqInterceptor)
                this._driver.interceptors.request.eject(this._reqInterceptor);
            if (this._resInterceptor)
                this._driver.interceptors.response.eject(this._resInterceptor);
        }
        return this;
    };
    Requester.prototype.clearHeaders = function () {
        this._driver.defaults.headers = {};
    };
    Requester.stringify = function (form) {
        return Object.keys(form)
            .map(function (k) {
            return encodeURIComponent(k) + "=" + encodeURIComponent(form[k]);
        })
            .join("&");
    };
    return Requester;
}());
exports.Requester = Requester;
